@@ -13,7 +13,7 @@ from CveXplore.api.connection.api_db import ApiDatabaseSource
 from CveXplore.common.db_mapping import database_mapping
 from CveXplore.database.connection.mongo_db import MongoDBConnection
 from CveXplore.errors import DatabaseIllegalCollection
-from CveXplore.lib.main_updater import MainUpdater
+from CveXplore.update.main_updater import MainUpdater
 
 try:
     from version import VERSION
